@@ -44,10 +44,12 @@ fn check_new_version() {
 		pkg_version,
 	);
 	if let Some(new_version) = informer.check_version().ok().flatten() {
-		log::info!(
-			"A new version of {pkg_name} is available: v{pkg_version} -> \
-			 {new_version}",
-		);
+		if new_version.semver().pre.is_empty() {
+			log::info!(
+				"A new version of {pkg_name} is available: v{pkg_version} -> \
+				 {new_version}",
+			);
+		}
 	}
 }
 
@@ -196,6 +198,11 @@ fn process_repository<'a>(
 		}
 	}
 
+	if release_index > 1 {
+		previous_release.previous = None;
+		releases[release_index].previous = Some(Box::new(previous_release));
+	}
+
 	// Add custom commit messages to the latest release.
 	if let Some(custom_commits) = &args.with_commit {
 		if let Some(latest_release) = releases.iter_mut().last() {
@@ -209,8 +216,9 @@ fn process_repository<'a>(
 
 	// Set the previous release if needed.
 	if args.latest || args.unreleased {
+		let sub = if args.latest { 2 } else { 1 };
 		if let Some((commit_id, version)) =
-			tags.len().checked_sub(2).and_then(|v| tags.get_index(v))
+			tags.len().checked_sub(sub).and_then(|v| tags.get_index(v))
 		{
 			let previous_release = Release {
 				commit_id: Some(commit_id.to_string()),
